==> james-project-3.5.0-source-release.zip: james-project-3.5.0/mailbox/plugin/quota-mailing/src/test/java/org/apache/james/mailbox/quota/mailing/listeners/QuotaThresholdCrossingListenerTest.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.james.mailbox.quota.mailing.listeners;

import static org.assertj.core.api.Assertions.assertThat;

import org.apache.james.mailbox.events.Group;
import org.junit.jupiter.api.Test;

class QuotaThresholdCrossingListenerTest {
    @Test
    void deserializeQuotaThresholdCrossingListenerGroup() throws Exception {
        assertThat(Group.deserialize("org.apache.james.mailbox.quota.mailing.listeners.QuotaThresholdCrossingListener$QuotaThresholdCrossingListenerGroup"))
            .isEqualTo(new QuotaThresholdCrossingListener.QuotaThresholdCrossingListenerGroup());
    }
}

==> james-project-3.8.2-source-release.zip: james-project-3.8.2/mailbox/plugin/quota-mailing/src/test/java/org/apache/james/mailbox/quota/mailing/listeners/QuotaThresholdCrossingListenerTest.java <==
/****************************************************************
 * Licensed to the Apache Software Foundation (ASF) under one   *
 * or more contributor license agreements.  See the NOTICE file *
 * distributed with this work for additional information        *
 * regarding copyright ownership.  The ASF licenses this file   *
 * to you under the Apache License, Version 2.0 (the            *
 * "License"); you may not use this file except in compliance   *
 * with the License.  You may obtain a copy of the License at   *
 *                                                              *
 *   http://www.apache.org/licenses/LICENSE-2.0                 *
 *                                                              *
 * Unless required by applicable law or agreed to in writing,   *
 * software distributed under the License is distributed on an  *
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY       *
 * KIND, either express or implied.  See the License for the    *
 * specific language governing permissions and limitations      *
 * under the License.                                           *
 ****************************************************************/

package org.apache.james.mailbox.quota.mailing.listeners;

import static org.assertj.core.api.Assertions.assertThat;

import org.apache.james.events.Group;
import org.junit.jupiter.api.Test;

class QuotaThresholdCrossingListenerTest {
    @Test
    void deserializeQuotaThresholdCrossingListenerGroup() throws Exception {
        assertThat(Group.deserialize("org.apache.james.mailbox.quota.mailing.listeners.QuotaThresholdCrossingListener$QuotaThresholdCrossingListenerGroup"))
            .isEqualTo(new QuotaThresholdCrossingListener.QuotaThresholdCrossingListenerGroup());
    }
}
